@@ -124,65 +124,4 @@ return(txt)
 
 
 
-## LINK TO README PAGE
-funreadme <- function(pkg, repos, eol) {
-    vec    <- c("README", "README.html", "readme.html", 
-                "readme/readme.html","readme/README.html")
-    urlvec <- file.path(repos, "web/packages", pkg, vec)
-    txt <- ""
-    for (urllink in urlvec) {
-        conurl <- tryCatch(url(urllink, open = "rb", method = "libcurl"), 
-                           condition = function(cond) {})
-        if (!is.null(conurl)) {
-            close(conurl)
-            txt <- paste0(txt, urllink, "")
-        }
-    }
-    if (grepl("\\\\", eol, fixed = TRUE) && (txt != "")[1L]) { 
-        txt <- paste0("\\url{", txt, "}")
-    }
-return(txt)
-}
-
-  
-## LINK TO NEWS PAGE
-funnews <- function(pkg, repos, eol) {
-    vec    <- c("NEWS", "NEWS.html", "news.html", 
-                "news/news.html", "news/NEWS.html")
-    urlvec <- file.path(repos, "web/packages", pkg, vec)
-    txt <- ""
-    for (urllink in urlvec) {
-        conurl <- tryCatch(url(urllink, open = "rb", method = "libcurl"), 
-                           condition = function(cond) {})
-        if (!is.null(conurl)) {
-            close(conurl)
-            txt <- paste0(txt, urllink, "")
-        }
-    }
-    if (grepl("\\\\", eol, fixed = TRUE) && (txt != "")[1L]) { 
-        txt <- paste0("\\url{", txt, "}")
-    }
-return(txt)
-}
-
-
-## LINKS TO VIGNETTES
-funvignettes <- function(pkg, repos, eol) {
-    urvi  <- paste0(repos, "/web/packages/", pkg, "/vignettes/index.rds") 
-    purv  <- paste0(repos, "/web/packages/", pkg, "/vignettes/") 
-    txt <- ""
-    convig <- tryCatch(gzcon(url(urvi, open = "rb", method = "libcurl")), 
-                       condition = function(cond) {})
-    if (!is.null(convig)) {
-        vigns   <- readRDS(convig)[,1]
-        close(convig)
-        txt <- paste0(txt, purv, vigns, "")
-    }
-    if (grepl("\\\\", eol, fixed = TRUE) && (txt != "")[1L]) { 
-        txt <- paste0("\\url{", txt, "}")
-    }
-return(txt)
-}
-
-
 
