@@ -22,7 +22,16 @@
 #' With the default configuration, this function downloads nothing. It is mostly 
 #' used to download one specific item which has not been previously downloaded. 
 #' 
-#' Visit \code{\link{p_downarch}} to download tar.gz file(s) from CRAN archive.
+#' \code{p_downarch} downloads from CRAN archive the tar.gz file of one or several 
+#' packages, either the last version(s) with \code{Sys.Date()} or the version(s) 
+#' before a given date. It combines 3 functions: \code{\link{p_archive_lst}} 
+#' lists the packages stored in CRAN archive and their version numbers, 
+#' \code{\link{l_targz}} extracts the appropriate version numbers available 
+#' before a given date, \code{targz_down} downloads the tar.gz files in the  
+#' selected directory (default is the current directory).
+#' 
+#' \code{targz_down} downloads the tar.gz files from CRAN archive to the selected
+#' directory (default is the current directory).
 #' 
 #' @param   ...        any format recognized by \code{\link{cnsc}}, including list.
 #'                     A vector or packages or a named list of packages (with names 
@@ -41,13 +50,26 @@
 #' @param   binary     logical. Download the *.tgz (Mac OSX) or *.zip (Windows) 
 #'                     binary file, depending the \code{type} value.
 #' @param   type       character. Either \code{"mac.binary"}, \code{"mac.binary.el-capitan"},   
-#'                     or \code{"win.binary"}. \code{"binary"} seems also accepted. 
-#'                     See the \code{type} section of \code{utils::install.packages}.
-#' @param   script     logical. Create a mini-script to test the package.
+#'                     or \code{"win.binary"}. The default, \code{"binary"}, 
+#'                     automatically detects the local OS and the variants
+#'                     between R-3.6.3, R-4.0.0 or (for Windows) gcc8. See the 
+#'                     \code{type} section of \code{utils::install.packages}.
+#' @param   script     logical. Create a mini-script and save it in a *.R file.
 #' @param   dir        character. The directory in which the files are saved. 
 #'                     Default value \code{"."} is the current directory.
 #' @param   crandb     data.frame \code{crandb}. The data.frame of CRAN packages.
 #' @param   repos      character. The address of your local CRAN.
+#' @param   before     character which can be converted to a Date, for instance 
+#'                     "2017-05-14". Extract from CRAN archive the package(s) 
+#'                     available before this date. Can be synchronized with
+#'                     the release dates of base-R versions listed at:  
+#'                     \url{https://CRAN.R-project.org/src/contrib/} and 
+#'                     \url{https://CRAN.R-project.org/package=rversions/readme/README.html}
+#' @param   url        character. The url address of CRAN archive html file.
+#' @param   ptargz     character. A vector of package(s) with their version number
+#'                     and tar.gz extension stored in CRAN archive. These packages
+#'                     can be identified with \code{\link{l_targz}}.
+#' 
 #' @examples
 #' ## In real life, download crandb from CRAN or load it from your directory 
 #' ## with functions crandb_down() or crandb_load(). 
@@ -55,11 +77,23 @@
 #' crandb_load(system.file("data", "zcrandb.rda", package = "RWsearch"))
 #' \donttest{
 #' ## Download the documentation in the "dirpkgs" directory. Flat representation.
-#' p_down(pacman, pdfsearch, sos, dir = "dirpkgs", repos = "https://cloud.r-project.org")
+#' dir <- file.path(tempdir(), "dirpkgs")
+#' p_down(RWsearch, pdfsearch, sos, dir = dir, repos = "https://cloud.r-project.org")
+#' list.files(dir, recursive = TRUE, full.names = TRUE)
 #' 
 #' ## Download the documentation in subdirectories named after the keywords.
+#' dir <- file.path(tempdir(), "dirpkgslist")
 #' (lst <- s_crandb_list(thermodynamic, "chemical reaction"))
-#' p_down(lst, dir = "dirpkgslist", repos = "https://cloud.r-project.org") 
+#' system.time(
+#'   p_down(lst, dir = dir, repos = "https://cloud.r-project.org")
+#' )
+#' list.files(dir, recursive = TRUE, full.names = TRUE)
+#' 
+#' ## Download tar.gz files stored in CRAN archive. 
+#' dir <- file.path(tempdir(), "targzip")
+#' p_downarch(fitur, zmatrix, NotAPkg, before = "2017-05-14", dir = dir)
+#' targz_down("SVN_1.0.tar.gz", dir = dir)
+#' list.files(dir, recursive = TRUE, full.names = TRUE)
 #' }
 #' @export
 #' @name p_down
@@ -120,6 +154,40 @@ p_down0 <- function(..., char = NULL, index = FALSE, manual = FALSE, vignettes =
            dir = dir, crandb = crandb, repos = repos) 
 }
 
+#' @export
+#' @rdname p_down
+p_downarch <- function(..., char = NULL, before = Sys.Date(), dir = ".",
+			    url = "https://cran.r-project.org/src/contrib/Archive") {
+    pkgs <- if (is.null(char)) cnscinfun() else char
+    if (is.list(pkgs)) stop("... (or char) cannot be a list.")
+	lst    <- p_archive_lst(char = pkgs, url = url)
+	ptargz <- l_targz(lst, before = before)
+	targz_down(ptargz, dir = dir, url = url)
+}
+
+#' @export
+#' @rdname p_down
+targz_down <- function(ptargz, dir = ".",
+			   url = "https://cran.r-project.org/src/contrib/Archive") {
+    if (is.list(ptargz)) stop("ptargz cannot be a list.")
+    if (length(ptargz) == 0) message("ptargz is empty. No file to download.") else {
+		if (any(!endsWith(ptargz, "tar.gz"))) stop("tar.gz extension is missing.")
+		dir2 <- gsub("\\", "/", path.expand(dir), fixed = TRUE)
+		if (!dir.exists(dir2)) dir.create(dir2, recursive = TRUE)
+		for (pkgtargz in ptargz) {
+			pkg <- substr(pkgtargz, 1, grepRaw("_", pkgtargz, fixed = TRUE)-1)
+			cran_file <- file.path(url, pkg, pkgtargz)
+			localfile <- file.path(dir2, pkgtargz)
+			trdc      <- trydownloadurl(cran_file, localfile)
+			if (trdc == 0) {
+				message(paste("Package", pkgtargz, "downloaded."))
+			} else {
+				message(paste("Package", pkgtargz, "not in CRAN Archive."))			
+			}
+		}
+	}
+}
+
 
 
 
