@@ -1,5 +1,5 @@
 ## p_html
-## @include p_down.R
+## @include p_graph.R
 
 
 #' @title HTML Help Page, PDF Manual and Vignettes
@@ -17,7 +17,8 @@
 #' \code{p_htmlweb} opens the default browser and displays the html help page of the package 
 #' housed by the University of Pennsylvania. An internet connexion is required.
 #' 
-#' \code{p_pdf} displays in a pdf reader the pdf manual of the package, or generates it on the fly 
+#' \code{p_pdf} displays in a pdf reader the pdf manual of the package, or generates 
+#' it on the fly 
 #' in the current directory if the package is installed. Miktex or Texlive is required. 
 #' This is a very fast function if the files already exist (and \code{overwrite= FALSE}) and 
 #' a (relatively) slow function if the files needs to be generated, usually much slower than:
@@ -32,20 +33,8 @@
 #' \code{p_vig_all} wraps \code{utils::browseVignettes(NULL)}. It opens the default browser 
 #' and displays all vignettes available in the computer. This can be a very large html file.
 #' 
-#' \code{p_check} opens the default browser, connects to your local CRAN and displays 
-#' for each package the CRAN Package Check Results or the last Check Results recorded in 
-#' CRAN archive (with the date of the archive). An internet connexion is required.
-#' A global table for package source Checks can be displayed with 
-#' \code{\link{h_cranchecks}}.
-#' A global table for Windows Binaries' package Check can be displayed with 
-#' \code{\link{h_crancheckwindows}}.
-#' 
-#' \code{p_check_lst} reads the check results from the repository and print 
-#' the results as a list, with a message if the package has been archived.  
-#' An internet connexion is required.
-#'  
-#' \code{p_archive} opens the default browser and displays the package archives.  
-#' An internet connexion is required.
+#' Use \code{\link{p_archive}} or \code{\link{p_archive}} to display in the browser 
+#' or in the console the package archives. An internet connexion is required.
 #'  
 #' 
 #' @param   ...        any format recognized by \code{\link{cnsc}}, except list.
@@ -59,13 +48,10 @@
 #'                     Default value \code{"."} is the current directory.
 #' @examples
 #' \donttest{
-#' p_page(pacman, sos, repos = "https://cloud.r-project.org") 
-#' p_html(pacman, sos) 
-#' p_htmlweb(pacman) 
-#' p_check(pacman, zmatrix, zonator, NotApkg, repos = "https://cloud.r-project.org") 
-#' p_check_lst(pacman, zmatrix, zonator, NotApkg, repos = "https://cloud.r-project.org") 
-#' p_archive(pacman)
-#' p_vig(pacman)
+#' p_page(RWsearch, sos, repos = "https://cloud.r-project.org") 
+#' p_html(RWsearch, sos) 
+#' p_htmlweb(RWsearch)
+#' p_vig(RWsearch)
 #' p_pdfweb(sos, repos = "https://cloud.r-project.org")
 #' p_pdf(sos, dir = file.path(tempdir(), "ppdf"))
 #' }
@@ -176,102 +162,6 @@ p_vig_all <- function() {
     utils::browseVignettes(NULL)
 }
 
-#' @export
-#' @rdname p_html
-p_check <- function(..., char = NULL, repos = getOption("repos")[1]) {
-    pkgs <- if (is.null(char)) cnscinfun() else char
-    if (is.list(pkgs)) stop("... (or char) cannot be a list.")
-    for (pkg in pkgs) {
-        urlc <- paste0(repos, "/web/checks/check_results_", pkg, ".html")
-		urli <- paste0(repos, "/web/packages/", pkg, "/index.html")
-		TCc  <- tryconurl(urlc)
-		if (inherits(TCc, "url")) {
-			## check_results normal
-			utils::browseURL(urlc)
-			close(TCc)
-		} else {
-			TCi <- tryconurl(urli, open = "rt")
-			if (inherits(TCi, "url")) {			
-				txt      <- readLines(TCi)
-				close(TCi)
-				lineArch <- txt[grep("Archived on", txt)]
-				subdate  <- substr(lineArch, 13, 22) 
-				if (length(subdate) == 0) {
-					## archived before 2018-02-04 without date
-					message(paste("Package", pkg, "was archived at an unknown date."))
-					utils::browseURL(urli)
-				} else {
-					## archived after 2018-02-04 with date
-					urld <- paste0("https://cran-archive.r-project.org/web/checks/", 
-								   substr(subdate, 1, 4), "/", subdate, "_check_results_", 
-								   pkg, ".html")
-					message(paste0("Package ", pkg, " is in CRAN Archive since ", subdate, "."))
-					utils::browseURL(urld)				
-				}
-			} else {
-				## pkg/index.html does not exist
-				message(paste("Package", pkg, "does not exist in CRAN or CRAN Archive."))
-			}	
-		}
-	}
-}
-
-#' @export
-#' @rdname p_html
-p_check_lst <- function (..., char = NULL, repos = getOption("repos")[1]) {
-    pkgs <- if (is.null(char)) cnscinfun() else char
-    if (is.list(pkgs)) stop("... (or char) cannot be a list.")
-	lst <- as.list(pkgs)
-	names(lst) <- pkgs
-    for (pkg in pkgs) {
-        urlc <- paste0(repos, "/web/checks/check_results_", pkg, ".html")
-		docc <- tempfile()
-		trdc <- trydownloadurl(urlc, docc)
-		if (trdc == 0) {
-			TABX   <- XML::readHTMLTable(docc, header = TRUE, which = 1, 
-							             stringsAsFactors = FALSE)
-			colnames(TABX) <- gsub(" ", "", colnames(TABX))
-			lst[[pkg]] <- TABX
-		} else {
-			urli <- paste0(repos, "/web/packages/", pkg, "/index.html")
-            TCi  <- tryconurl(urli, open = "rt")
-            if (inherits(TCi, "url")) {
-                txt <- readLines(TCi)
-                close(TCi)
-                lineArch <- txt[grep("Archived on", txt)]
-                subdate  <- substr(lineArch, 13, 22)
-                if (length(subdate) == 0) {
-                  lst[[pkg]] <- paste("Package", pkg, "was archived at an unknown date.")
-                } else {
-					urld <- paste0("https://cran-archive.r-project.org/web/checks/", 
-                                   substr(subdate, 1, 4), "/", subdate, "_check_results_", pkg, ".html")
-					docd <- tempfile()
-					trdd <- trydownloadurl(urld, docd)
-					TABX <- XML::readHTMLTable(docd, header = TRUE, which = 1, 
-											   stringsAsFactors = FALSE)
-					colnames(TABX) <- gsub(" ", "", colnames(TABX))
-					message(paste0("Package ", pkg, " is in CRAN Archive since ", subdate, "."))
-					lst[[pkg]] <- TABX
-                }		
-            } else {
-					lst[[pkg]] <- paste("Package", pkg, "does not exist in CRAN or CRAN Archive.")
-            }		
-		}
-	}
-return(lst)
-}
-
-#' @export
-#' @rdname p_html
-p_archive <- function(..., char = NULL) {
-    pkgs <- if (is.null(char)) cnscinfun() else char
-    if (is.list(pkgs)) stop("... (or char) cannot be a list.")
-    for (pkg in pkgs) {
-        url <- paste0("https://cran.r-project.org/src/contrib/Archive/", pkg, "/")
-        utils::browseURL(url)
-    }
-}
-
 
 
 ## Generate the pdf manual of a package listed in .libPaths()
